@@ -1019,10 +1019,10 @@ class TicketAPIMixin:
         endpoint_url = '{}/{}'.format(self.ENDPOINT_TICKETS, ticket_id)
         return self.fetch_resource(endpoint_url)
 
-    def get_ticket_tasks(self, ticket_id):
+    def get_ticket_tasks(self, ticket_id, **kwargs):
         endpoint_url = '{}/{}/tasks'.format(
             self.ENDPOINT_TICKETS, ticket_id)
-        return self.fetch_resource(endpoint_url, should_page=True)
+        return self.fetch_resource(endpoint_url, should_page=True, **kwargs)
 
     def create_ticket_task(self, ticket_id, **kwargs):
         endpoint_url = '{}/{}/tasks'.format(
