@@ -48,6 +48,26 @@ class TestConnectWiseAPIClient(TestCase):
             '(closedFlag=False)'
         )
 
+    def test_cw_cloud_url(self):
+        client = api.ServiceAPIClient()
+        self.assertEqual(client.server_url, 'https://localhost')
+
+        client = api.ServiceAPIClient(
+            server_url='https://na.myconnectwise.net'
+        )
+        self.assertEqual(
+            client.server_url,
+            'https://api-na.myconnectwise.net'
+        )
+
+        client = api.ServiceAPIClient(
+            server_url='https://api-na.myconnectwise.net'
+        )
+        self.assertEqual(
+            client.server_url,
+            'https://api-na.myconnectwise.net'
+        )
+
     def test_prepare_conditions_multiple(self):
         test_date = date(1948, 5, 14)
         test_time = time(12, 0, 0, tzinfo=timezone.get_current_timezone())
@@ -206,6 +226,72 @@ class TestServiceAPIClient(BaseAPITestCase):
         self.assert_request_should_page(True)
 
 
+class TestHostedAPIClient(BaseAPITestCase):
+
+    def setUp(self):
+        self.client = api.HostedAPIClient()
+
+    @responses.activate
+    def test_post_hosted_tab(self):
+        body = {
+            'screenId': fixtures.API_HOSTED_SCREENS['row_values'][3],
+            'description': 'A new hosted tab',
+            'url': 'https://example.com',
+            'type': 'Tab'
+        }
+
+        method_name = 'djconnectwise.api.ConnectWiseAPIClient.request'
+        mock_call, _patch = mk.create_mock_call(
+            method_name,
+            body)
+
+        self.client.post_hosted_tab(
+            screen_id=fixtures.API_HOSTED_SCREENS['row_values'][3],
+            description='A new hosted tab',
+            origin_url='https://example.com',
+            type='Tab'
+        )
+        self.assertEqual(mock_call.call_count, 1)
+
+    @responses.activate
+    def test_get_hosted_tabs(self):
+        endpoint_url = \
+            self.client._endpoint(self.client.ENDPOINT_HOSTED_SETUPS)
+
+        mk.get(endpoint_url, fixtures.API_HOSTED_SETUPS)
+
+        result = self.client.get_hosted_tabs()
+        self.assertEqual(result, fixtures.API_HOSTED_SETUPS)
+
+    @responses.activate
+    def test_delete_hosted_tab(self):
+        object_id = 27
+        method_name = 'requests.request'
+        mock_call, _patch = mk.create_mock_call(
+            method_name,
+            "201 Created")
+
+        self.client.delete_hosted_tab(object_id)
+        self.assertEqual(mock_call.call_count, 1)
+
+
+class TestHostedReportAPIClient(BaseAPITestCase):
+
+    def setUp(self):
+        self.client = api.HostedReportAPIClient()
+
+    @responses.activate
+    def test_get_hosted_screen_ids(self):
+        endpoint_url = \
+            self.client._endpoint(self.client.ENDPOINT_HOSTED_REPORT)
+
+        mk.get(endpoint_url, fixtures.API_HOSTED_SCREENS)
+
+        result = self.client.get_hosted_screen_ids()
+        self.assertEqual(result, fixtures.API_HOSTED_SCREENS)
+        self.assert_request_should_page(False)
+
+
 class TestSystemAPIClient(BaseAPITestCase):
 
     def setUp(self):
@@ -417,7 +503,8 @@ class TestScheduleAPIClient(BaseAPITestCase):
         schedule_type = SimpleNamespace()
         schedule_type.id = 4
         schedule_type.identifier = 'S'
-        object_id = 69
+        ticket_object = SimpleNamespace()
+        ticket_object.id = 4
 
         method_name = 'djconnectwise.api.ConnectWiseAPIClient.request'
         mock_call, _patch = mk.create_mock_call(
@@ -426,9 +513,8 @@ class TestScheduleAPIClient(BaseAPITestCase):
         self.client = api.ScheduleAPIClient()
 
         self.client.post_schedule_entry(
-            objectId=object_id,
-            scheduleType=schedule_type,
-            resource=member)
+            ticket_object,
+            schedule_type)
         self.assertEqual(mock_call.call_count, 1)
 
     @responses.activate
@@ -444,6 +530,42 @@ class TestScheduleAPIClient(BaseAPITestCase):
         self.assertEqual(mock_call.call_count, 1)
 
 
+class TestTimeAPIClient(BaseAPITestCase):
+
+    def setUp(self):
+        super(TestTimeAPIClient, self).setUp()
+        self.client = api.TimeAPIClient()
+        self.endpoint = self.client._endpoint(self.client.ENDPOINT_ENTRIES)
+
+    @responses.activate
+    def test_get_time_entries(self):
+        endpoint = self.client._endpoint(self.client.ENDPOINT_ENTRIES)
+
+        mk.get(endpoint, fixtures.API_TIME_ENTRY_LIST)
+        result = self.client.get_time_entries()
+        self.assertEqual(result, fixtures.API_TIME_ENTRY_LIST)
+        self.assert_request_should_page(True)
+
+    @responses.activate
+    def test_post_time_entry(self):
+        method_name = 'djconnectwise.api.ConnectWiseAPIClient.request'
+        mock_call, _patch = mk.create_mock_call(
+            method_name,
+            fixtures.API_TIME_ENTRY)
+        self.client = api.TimeAPIClient()
+
+        target_data = {
+            'id': 1,
+            'type': "ServiceTicket",
+        }
+
+        self.client.post_time_entry(
+            target_data,
+            time_start=timezone.now(),
+        )
+        self.assertEqual(mock_call.call_count, 1)
+
+
 class TestFetchAPICodebase(TestCase):
     HOST = 'https://na.myconnectwise.net'
     COMPANY_ID = 'foobar'
@@ -569,6 +691,26 @@ class TestSalesAPIClient(BaseAPITestCase):
         self.assertEqual(result, fixtures.API_SALES_ACTIVITIES)
         self.assert_request_should_page(True)
 
+    @responses.activate
+    def test_get_activity_statuses(self):
+        endpoint = self.client._endpoint(
+            self.client.ENDPOINT_ACTIVITY_STATUSES)
+
+        mk.get(endpoint, fixtures.API_SALES_ACTIVITY_STATUSES)
+        result = self.client.get_activity_statuses()
+        self.assertEqual(result, fixtures.API_SALES_ACTIVITY_STATUSES)
+        self.assert_request_should_page(True)
+
+    @responses.activate
+    def test_get_activity_types(self):
+        endpoint = self.client._endpoint(
+            self.client.ENDPOINT_ACTIVITY_TYPES)
+
+        mk.get(endpoint, fixtures.API_SALES_ACTIVITY_TYPES)
+        result = self.client.get_activity_types()
+        self.assertEqual(result, fixtures.API_SALES_ACTIVITY_TYPES)
+        self.assert_request_should_page(True)
+
     @responses.activate
     def test_get_single_activity(self):
         endpoint = self.client._endpoint(
@@ -725,3 +867,19 @@ class TestAPISettings(TestCase):
             retry_counter['count'],
             api.ServiceAPIClient.MAX_404_ATTEMPTS + 1
         )
+
+
+class TestFinanceAPIClient(BaseAPITestCase):
+
+    def setUp(self):
+        super(TestFinanceAPIClient, self).setUp()
+        self.client = api.FinanceAPIClient()
+        self.endpoint = self.client._endpoint(self.client.ENDPOINT_AGREEMENTS)
+
+    @responses.activate
+    def test_get_agreements(self):
+        mk.get(self.endpoint, fixtures.API_AGREEMENT_LIST)
+        result = self.client.get_agreements()
+
+        self.assertEqual(result, fixtures.API_AGREEMENT_LIST)
+        self.assert_request_should_page(True)
